# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import account_pb2 as gateway_dot_account__pb2
from . import aws_iam_role_binding_pb2 as gateway_dot_aws__iam__role__binding__pb2
from . import batch_job_pb2 as gateway_dot_batch__job__pb2
from . import cluster_pb2 as gateway_dot_cluster__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import environment_pb2 as gateway_dot_environment__pb2
from . import model_pb2 as gateway_dot_model__pb2
from . import node_pool_pb2 as gateway_dot_node__pool__pb2
from . import sign_in_pb2 as gateway_dot_sign__in__pb2
from . import snapshot_pb2 as gateway_dot_snapshot__pb2
from . import user_pb2 as gateway_dot_user__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/gateway.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15gateway/gateway.proto\x12\x07gateway\x1a\x15gateway/account.proto\x1a\"gateway/aws_iam_role_binding.proto\x1a\x17gateway/batch_job.proto\x1a\x15gateway/cluster.proto\x1a\x18gateway/deployment.proto\x1a\x19gateway/environment.proto\x1a\x13gateway/model.proto\x1a\x17gateway/node_pool.proto\x1a\x15gateway/sign_in.proto\x1a\x16gateway/snapshot.proto\x1a\x12gateway/user.proto\x1a\x1bgoogle/protobuf/empty.proto2\xb7&\n\x07Gateway\x12:\n\x06SignIn\x12\x16.gateway.SignInRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x11GetOAuthArguments\x12!.gateway.GetOAuthArgumentsRequest\x1a\".gateway.GetOAuthArgumentsResponse\"\x00\x12\x42\n\rCreateAccount\x12\x1d.gateway.CreateAccountRequest\x1a\x10.gateway.Account\"\x00\x12<\n\nGetAccount\x12\x1a.gateway.GetAccountRequest\x1a\x10.gateway.Account\"\x00\x12M\n\x0cListAccounts\x12\x1c.gateway.ListAccountsRequest\x1a\x1d.gateway.ListAccountsResponse\"\x00\x12\x42\n\rUpdateAccount\x12\x1d.gateway.UpdateAccountRequest\x1a\x10.gateway.Account\"\x00\x12H\n\rDeleteAccount\x12\x1d.gateway.DeleteAccountRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x45\n\x0e\x43reateBatchJob\x12\x1e.gateway.CreateBatchJobRequest\x1a\x11.gateway.BatchJob\"\x00\x12?\n\x0bGetBatchJob\x12\x1b.gateway.GetBatchJobRequest\x1a\x11.gateway.BatchJob\"\x00\x12P\n\rListBatchJobs\x12\x1d.gateway.ListBatchJobsRequest\x1a\x1e.gateway.ListBatchJobsResponse\"\x00\x12J\n\x0e\x44\x65leteBatchJob\x12\x1e.gateway.DeleteBatchJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x14\x42\x61tchDeleteBatchJobs\x12$.gateway.BatchDeleteBatchJobsRequest\x1a\x16.google.protobuf.Empty\"\x00\x12J\n\x0e\x43\x61ncelBatchJob\x12\x1e.gateway.CancelBatchJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x42\n\rCreateCluster\x12\x1d.gateway.CreateClusterRequest\x1a\x10.gateway.Cluster\"\x00\x12<\n\nGetCluster\x12\x1a.gateway.GetClusterRequest\x1a\x10.gateway.Cluster\"\x00\x12M\n\x0cListClusters\x12\x1c.gateway.ListClustersRequest\x1a\x1d.gateway.ListClustersResponse\"\x00\x12\x42\n\rUpdateCluster\x12\x1d.gateway.UpdateClusterRequest\x1a\x10.gateway.Cluster\"\x00\x12H\n\rDeleteCluster\x12\x1d.gateway.DeleteClusterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x18GetClusterConnectionInfo\x12(.gateway.GetClusterConnectionInfoRequest\x1a\x1e.gateway.ClusterConnectionInfo\"\x00\x12N\n\x11\x43reateEnvironment\x12!.gateway.CreateEnvironmentRequest\x1a\x14.gateway.Environment\"\x00\x12H\n\x0eGetEnvironment\x12\x1e.gateway.GetEnvironmentRequest\x1a\x14.gateway.Environment\"\x00\x12Y\n\x10ListEnvironments\x12 .gateway.ListEnvironmentsRequest\x1a!.gateway.ListEnvironmentsResponse\"\x00\x12N\n\x11UpdateEnvironment\x12!.gateway.UpdateEnvironmentRequest\x1a\x14.gateway.Environment\"\x00\x12P\n\x11\x44\x65leteEnvironment\x12!.gateway.DeleteEnvironmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x17\x42\x61tchDeleteEnvironments\x12\'.gateway.BatchDeleteEnvironmentsRequest\x1a\x16.google.protobuf.Empty\"\x00\x12R\n\x12\x43onnectEnvironment\x12\".gateway.ConnectEnvironmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12X\n\x15\x44isconnectEnvironment\x12%.gateway.DisconnectEnvironmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x45\n\x0e\x43reateSnapshot\x12\x1e.gateway.CreateSnapshotRequest\x1a\x11.gateway.Snapshot\"\x00\x12?\n\x0bGetSnapshot\x12\x1b.gateway.GetSnapshotRequest\x1a\x11.gateway.Snapshot\"\x00\x12P\n\rListSnapshots\x12\x1d.gateway.ListSnapshotsRequest\x1a\x1e.gateway.ListSnapshotsResponse\"\x00\x12J\n\x0e\x44\x65leteSnapshot\x12\x1e.gateway.DeleteSnapshotRequest\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x0fGetBatchJobLogs\x12\x1f.gateway.GetBatchJobLogsRequest\x1a .gateway.GetBatchJobLogsResponse\"\x00\x12\x45\n\x0e\x43reateNodePool\x12\x1e.gateway.CreateNodePoolRequest\x1a\x11.gateway.NodePool\"\x00\x12?\n\x0bGetNodePool\x12\x1b.gateway.GetNodePoolRequest\x1a\x11.gateway.NodePool\"\x00\x12P\n\rListNodePools\x12\x1d.gateway.ListNodePoolsRequest\x1a\x1e.gateway.ListNodePoolsResponse\"\x00\x12\x45\n\x0eUpdateNodePool\x12\x1e.gateway.UpdateNodePoolRequest\x1a\x11.gateway.NodePool\"\x00\x12J\n\x0e\x44\x65leteNodePool\x12\x1e.gateway.DeleteNodePoolRequest\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x14\x42\x61tchDeleteNodePools\x12$.gateway.BatchDeleteNodePoolsRequest\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\x10GetNodePoolStats\x12 .gateway.GetNodePoolStatsRequest\x1a\x16.gateway.NodePoolStats\"\x00\x12\x39\n\nCreateUser\x12\x1a.gateway.CreateUserRequest\x1a\r.gateway.User\"\x00\x12\x33\n\x07GetUser\x12\x17.gateway.GetUserRequest\x1a\r.gateway.User\"\x00\x12\x44\n\tListUsers\x12\x19.gateway.ListUsersRequest\x1a\x1a.gateway.ListUsersResponse\"\x00\x12\x39\n\nUpdateUser\x12\x1a.gateway.UpdateUserRequest\x1a\r.gateway.User\"\x00\x12\x42\n\nDeleteUser\x12\x1a.gateway.DeleteUserRequest\x1a\x16.google.protobuf.Empty\"\x00\x12<\n\x0b\x43reateModel\x12\x1b.gateway.CreateModelRequest\x1a\x0e.gateway.Model\"\x00\x12\x36\n\x08GetModel\x12\x18.gateway.GetModelRequest\x1a\x0e.gateway.Model\"\x00\x12G\n\nListModels\x12\x1a.gateway.ListModelsRequest\x1a\x1b.gateway.ListModelsResponse\"\x00\x12<\n\x0bUpdateModel\x12\x1b.gateway.UpdateModelRequest\x1a\x0e.gateway.Model\"\x00\x12\x44\n\x0b\x44\x65leteModel\x12\x1b.gateway.DeleteModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12k\n\x16GetModelUploadEndpoint\x12&.gateway.GetModelUploadEndpointRequest\x1a\'.gateway.GetModelUploadEndpointResponse\"\x00\x12T\n\x13ValidateModelUpload\x12#.gateway.ValidateModelUploadRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x44\n\x0b\x44\x65ployModel\x12\x1b.gateway.DeployModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12H\n\rUndeployModel\x12\x1d.gateway.UndeployModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12K\n\x10\x43reateDeployment\x12 .gateway.CreateDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12\x45\n\rGetDeployment\x12\x1d.gateway.GetDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12I\n\x0fStartDeployment\x12\x1f.gateway.StartDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12V\n\x0fListDeployments\x12\x1f.gateway.ListDeploymentsRequest\x1a .gateway.ListDeploymentsResponse\"\x00\x12K\n\x10UpdateDeployment\x12 .gateway.UpdateDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12N\n\x10\x44\x65leteDeployment\x12 .gateway.DeleteDeploymentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12`\n\x17\x43reateAwsIamRoleBinding\x12\'.gateway.CreateAwsIamRoleBindingRequest\x1a\x1a.gateway.AwsIamRoleBinding\"\x00\x12k\n\x16ListAwsIamRoleBindings\x12&.gateway.ListAwsIamRoleBindingsRequest\x1a\'.gateway.ListAwsIamRoleBindingsResponse\"\x00\x12\\\n\x17\x44\x65leteAwsIamRoleBinding\x12\'.gateway.DeleteAwsIamRoleBindingRequest\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\x10ReconcileCluster\x12 .gateway.ReconcileClusterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12P\n\x11ReconcileNodePool\x12!.gateway.ReconcileNodePoolRequest\x1a\x16.google.protobuf.Empty\"\x00\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_account__pb2.DESCRIPTOR,gateway_dot_aws__iam__role__binding__pb2.DESCRIPTOR,gateway_dot_batch__job__pb2.DESCRIPTOR,gateway_dot_cluster__pb2.DESCRIPTOR,gateway_dot_deployment__pb2.DESCRIPTOR,gateway_dot_environment__pb2.DESCRIPTOR,gateway_dot_model__pb2.DESCRIPTOR,gateway_dot_node__pool__pb2.DESCRIPTOR,gateway_dot_sign__in__pb2.DESCRIPTOR,gateway_dot_snapshot__pb2.DESCRIPTOR,gateway_dot_user__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_GATEWAY = _descriptor.ServiceDescriptor(
  name='Gateway',
  full_name='gateway.Gateway',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=337,
  serialized_end=5256,
  methods=[
  _descriptor.MethodDescriptor(
    name='SignIn',
    full_name='gateway.Gateway.SignIn',
    index=0,
    containing_service=None,
    input_type=gateway_dot_sign__in__pb2._SIGNINREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOAuthArguments',
    full_name='gateway.Gateway.GetOAuthArguments',
    index=1,
    containing_service=None,
    input_type=gateway_dot_sign__in__pb2._GETOAUTHARGUMENTSREQUEST,
    output_type=gateway_dot_sign__in__pb2._GETOAUTHARGUMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAccount',
    full_name='gateway.Gateway.CreateAccount',
    index=2,
    containing_service=None,
    input_type=gateway_dot_account__pb2._CREATEACCOUNTREQUEST,
    output_type=gateway_dot_account__pb2._ACCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccount',
    full_name='gateway.Gateway.GetAccount',
    index=3,
    containing_service=None,
    input_type=gateway_dot_account__pb2._GETACCOUNTREQUEST,
    output_type=gateway_dot_account__pb2._ACCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccounts',
    full_name='gateway.Gateway.ListAccounts',
    index=4,
    containing_service=None,
    input_type=gateway_dot_account__pb2._LISTACCOUNTSREQUEST,
    output_type=gateway_dot_account__pb2._LISTACCOUNTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccount',
    full_name='gateway.Gateway.UpdateAccount',
    index=5,
    containing_service=None,
    input_type=gateway_dot_account__pb2._UPDATEACCOUNTREQUEST,
    output_type=gateway_dot_account__pb2._ACCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAccount',
    full_name='gateway.Gateway.DeleteAccount',
    index=6,
    containing_service=None,
    input_type=gateway_dot_account__pb2._DELETEACCOUNTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBatchJob',
    full_name='gateway.Gateway.CreateBatchJob',
    index=7,
    containing_service=None,
    input_type=gateway_dot_batch__job__pb2._CREATEBATCHJOBREQUEST,
    output_type=gateway_dot_batch__job__pb2._BATCHJOB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBatchJob',
    full_name='gateway.Gateway.GetBatchJob',
    index=8,
    containing_service=None,
    input_type=gateway_dot_batch__job__pb2._GETBATCHJOBREQUEST,
    output_type=gateway_dot_batch__job__pb2._BATCHJOB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListBatchJobs',
    full_name='gateway.Gateway.ListBatchJobs',
    index=9,
    containing_service=None,
    input_type=gateway_dot_batch__job__pb2._LISTBATCHJOBSREQUEST,
    output_type=gateway_dot_batch__job__pb2._LISTBATCHJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteBatchJob',
    full_name='gateway.Gateway.DeleteBatchJob',
    index=10,
    containing_service=None,
    input_type=gateway_dot_batch__job__pb2._DELETEBATCHJOBREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchDeleteBatchJobs',
    full_name='gateway.Gateway.BatchDeleteBatchJobs',
    index=11,
    containing_service=None,
    input_type=gateway_dot_batch__job__pb2._BATCHDELETEBATCHJOBSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelBatchJob',
    full_name='gateway.Gateway.CancelBatchJob',
    index=12,
    containing_service=None,
    input_type=gateway_dot_batch__job__pb2._CANCELBATCHJOBREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCluster',
    full_name='gateway.Gateway.CreateCluster',
    index=13,
    containing_service=None,
    input_type=gateway_dot_cluster__pb2._CREATECLUSTERREQUEST,
    output_type=gateway_dot_cluster__pb2._CLUSTER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCluster',
    full_name='gateway.Gateway.GetCluster',
    index=14,
    containing_service=None,
    input_type=gateway_dot_cluster__pb2._GETCLUSTERREQUEST,
    output_type=gateway_dot_cluster__pb2._CLUSTER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListClusters',
    full_name='gateway.Gateway.ListClusters',
    index=15,
    containing_service=None,
    input_type=gateway_dot_cluster__pb2._LISTCLUSTERSREQUEST,
    output_type=gateway_dot_cluster__pb2._LISTCLUSTERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCluster',
    full_name='gateway.Gateway.UpdateCluster',
    index=16,
    containing_service=None,
    input_type=gateway_dot_cluster__pb2._UPDATECLUSTERREQUEST,
    output_type=gateway_dot_cluster__pb2._CLUSTER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCluster',
    full_name='gateway.Gateway.DeleteCluster',
    index=17,
    containing_service=None,
    input_type=gateway_dot_cluster__pb2._DELETECLUSTERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClusterConnectionInfo',
    full_name='gateway.Gateway.GetClusterConnectionInfo',
    index=18,
    containing_service=None,
    input_type=gateway_dot_cluster__pb2._GETCLUSTERCONNECTIONINFOREQUEST,
    output_type=gateway_dot_cluster__pb2._CLUSTERCONNECTIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateEnvironment',
    full_name='gateway.Gateway.CreateEnvironment',
    index=19,
    containing_service=None,
    input_type=gateway_dot_environment__pb2._CREATEENVIRONMENTREQUEST,
    output_type=gateway_dot_environment__pb2._ENVIRONMENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEnvironment',
    full_name='gateway.Gateway.GetEnvironment',
    index=20,
    containing_service=None,
    input_type=gateway_dot_environment__pb2._GETENVIRONMENTREQUEST,
    output_type=gateway_dot_environment__pb2._ENVIRONMENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEnvironments',
    full_name='gateway.Gateway.ListEnvironments',
    index=21,
    containing_service=None,
    input_type=gateway_dot_environment__pb2._LISTENVIRONMENTSREQUEST,
    output_type=gateway_dot_environment__pb2._LISTENVIRONMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateEnvironment',
    full_name='gateway.Gateway.UpdateEnvironment',
    index=22,
    containing_service=None,
    input_type=gateway_dot_environment__pb2._UPDATEENVIRONMENTREQUEST,
    output_type=gateway_dot_environment__pb2._ENVIRONMENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteEnvironment',
    full_name='gateway.Gateway.DeleteEnvironment',
    index=23,
    containing_service=None,
    input_type=gateway_dot_environment__pb2._DELETEENVIRONMENTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchDeleteEnvironments',
    full_name='gateway.Gateway.BatchDeleteEnvironments',
    index=24,
    containing_service=None,
    input_type=gateway_dot_environment__pb2._BATCHDELETEENVIRONMENTSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConnectEnvironment',
    full_name='gateway.Gateway.ConnectEnvironment',
    index=25,
    containing_service=None,
    input_type=gateway_dot_environment__pb2._CONNECTENVIRONMENTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisconnectEnvironment',
    full_name='gateway.Gateway.DisconnectEnvironment',
    index=26,
    containing_service=None,
    input_type=gateway_dot_environment__pb2._DISCONNECTENVIRONMENTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSnapshot',
    full_name='gateway.Gateway.CreateSnapshot',
    index=27,
    containing_service=None,
    input_type=gateway_dot_snapshot__pb2._CREATESNAPSHOTREQUEST,
    output_type=gateway_dot_snapshot__pb2._SNAPSHOT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSnapshot',
    full_name='gateway.Gateway.GetSnapshot',
    index=28,
    containing_service=None,
    input_type=gateway_dot_snapshot__pb2._GETSNAPSHOTREQUEST,
    output_type=gateway_dot_snapshot__pb2._SNAPSHOT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSnapshots',
    full_name='gateway.Gateway.ListSnapshots',
    index=29,
    containing_service=None,
    input_type=gateway_dot_snapshot__pb2._LISTSNAPSHOTSREQUEST,
    output_type=gateway_dot_snapshot__pb2._LISTSNAPSHOTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSnapshot',
    full_name='gateway.Gateway.DeleteSnapshot',
    index=30,
    containing_service=None,
    input_type=gateway_dot_snapshot__pb2._DELETESNAPSHOTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBatchJobLogs',
    full_name='gateway.Gateway.GetBatchJobLogs',
    index=31,
    containing_service=None,
    input_type=gateway_dot_batch__job__pb2._GETBATCHJOBLOGSREQUEST,
    output_type=gateway_dot_batch__job__pb2._GETBATCHJOBLOGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNodePool',
    full_name='gateway.Gateway.CreateNodePool',
    index=32,
    containing_service=None,
    input_type=gateway_dot_node__pool__pb2._CREATENODEPOOLREQUEST,
    output_type=gateway_dot_node__pool__pb2._NODEPOOL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNodePool',
    full_name='gateway.Gateway.GetNodePool',
    index=33,
    containing_service=None,
    input_type=gateway_dot_node__pool__pb2._GETNODEPOOLREQUEST,
    output_type=gateway_dot_node__pool__pb2._NODEPOOL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListNodePools',
    full_name='gateway.Gateway.ListNodePools',
    index=34,
    containing_service=None,
    input_type=gateway_dot_node__pool__pb2._LISTNODEPOOLSREQUEST,
    output_type=gateway_dot_node__pool__pb2._LISTNODEPOOLSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNodePool',
    full_name='gateway.Gateway.UpdateNodePool',
    index=35,
    containing_service=None,
    input_type=gateway_dot_node__pool__pb2._UPDATENODEPOOLREQUEST,
    output_type=gateway_dot_node__pool__pb2._NODEPOOL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteNodePool',
    full_name='gateway.Gateway.DeleteNodePool',
    index=36,
    containing_service=None,
    input_type=gateway_dot_node__pool__pb2._DELETENODEPOOLREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchDeleteNodePools',
    full_name='gateway.Gateway.BatchDeleteNodePools',
    index=37,
    containing_service=None,
    input_type=gateway_dot_node__pool__pb2._BATCHDELETENODEPOOLSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNodePoolStats',
    full_name='gateway.Gateway.GetNodePoolStats',
    index=38,
    containing_service=None,
    input_type=gateway_dot_node__pool__pb2._GETNODEPOOLSTATSREQUEST,
    output_type=gateway_dot_node__pool__pb2._NODEPOOLSTATS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateUser',
    full_name='gateway.Gateway.CreateUser',
    index=39,
    containing_service=None,
    input_type=gateway_dot_user__pb2._CREATEUSERREQUEST,
    output_type=gateway_dot_user__pb2._USER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUser',
    full_name='gateway.Gateway.GetUser',
    index=40,
    containing_service=None,
    input_type=gateway_dot_user__pb2._GETUSERREQUEST,
    output_type=gateway_dot_user__pb2._USER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUsers',
    full_name='gateway.Gateway.ListUsers',
    index=41,
    containing_service=None,
    input_type=gateway_dot_user__pb2._LISTUSERSREQUEST,
    output_type=gateway_dot_user__pb2._LISTUSERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateUser',
    full_name='gateway.Gateway.UpdateUser',
    index=42,
    containing_service=None,
    input_type=gateway_dot_user__pb2._UPDATEUSERREQUEST,
    output_type=gateway_dot_user__pb2._USER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUser',
    full_name='gateway.Gateway.DeleteUser',
    index=43,
    containing_service=None,
    input_type=gateway_dot_user__pb2._DELETEUSERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModel',
    full_name='gateway.Gateway.CreateModel',
    index=44,
    containing_service=None,
    input_type=gateway_dot_model__pb2._CREATEMODELREQUEST,
    output_type=gateway_dot_model__pb2._MODEL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModel',
    full_name='gateway.Gateway.GetModel',
    index=45,
    containing_service=None,
    input_type=gateway_dot_model__pb2._GETMODELREQUEST,
    output_type=gateway_dot_model__pb2._MODEL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListModels',
    full_name='gateway.Gateway.ListModels',
    index=46,
    containing_service=None,
    input_type=gateway_dot_model__pb2._LISTMODELSREQUEST,
    output_type=gateway_dot_model__pb2._LISTMODELSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModel',
    full_name='gateway.Gateway.UpdateModel',
    index=47,
    containing_service=None,
    input_type=gateway_dot_model__pb2._UPDATEMODELREQUEST,
    output_type=gateway_dot_model__pb2._MODEL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModel',
    full_name='gateway.Gateway.DeleteModel',
    index=48,
    containing_service=None,
    input_type=gateway_dot_model__pb2._DELETEMODELREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelUploadEndpoint',
    full_name='gateway.Gateway.GetModelUploadEndpoint',
    index=49,
    containing_service=None,
    input_type=gateway_dot_model__pb2._GETMODELUPLOADENDPOINTREQUEST,
    output_type=gateway_dot_model__pb2._GETMODELUPLOADENDPOINTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateModelUpload',
    full_name='gateway.Gateway.ValidateModelUpload',
    index=50,
    containing_service=None,
    input_type=gateway_dot_model__pb2._VALIDATEMODELUPLOADREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeployModel',
    full_name='gateway.Gateway.DeployModel',
    index=51,
    containing_service=None,
    input_type=gateway_dot_model__pb2._DEPLOYMODELREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UndeployModel',
    full_name='gateway.Gateway.UndeployModel',
    index=52,
    containing_service=None,
    input_type=gateway_dot_model__pb2._UNDEPLOYMODELREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDeployment',
    full_name='gateway.Gateway.CreateDeployment',
    index=53,
    containing_service=None,
    input_type=gateway_dot_deployment__pb2._CREATEDEPLOYMENTREQUEST,
    output_type=gateway_dot_deployment__pb2._DEPLOYMENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDeployment',
    full_name='gateway.Gateway.GetDeployment',
    index=54,
    containing_service=None,
    input_type=gateway_dot_deployment__pb2._GETDEPLOYMENTREQUEST,
    output_type=gateway_dot_deployment__pb2._DEPLOYMENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartDeployment',
    full_name='gateway.Gateway.StartDeployment',
    index=55,
    containing_service=None,
    input_type=gateway_dot_deployment__pb2._STARTDEPLOYMENTREQUEST,
    output_type=gateway_dot_deployment__pb2._DEPLOYMENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDeployments',
    full_name='gateway.Gateway.ListDeployments',
    index=56,
    containing_service=None,
    input_type=gateway_dot_deployment__pb2._LISTDEPLOYMENTSREQUEST,
    output_type=gateway_dot_deployment__pb2._LISTDEPLOYMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDeployment',
    full_name='gateway.Gateway.UpdateDeployment',
    index=57,
    containing_service=None,
    input_type=gateway_dot_deployment__pb2._UPDATEDEPLOYMENTREQUEST,
    output_type=gateway_dot_deployment__pb2._DEPLOYMENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDeployment',
    full_name='gateway.Gateway.DeleteDeployment',
    index=58,
    containing_service=None,
    input_type=gateway_dot_deployment__pb2._DELETEDEPLOYMENTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAwsIamRoleBinding',
    full_name='gateway.Gateway.CreateAwsIamRoleBinding',
    index=59,
    containing_service=None,
    input_type=gateway_dot_aws__iam__role__binding__pb2._CREATEAWSIAMROLEBINDINGREQUEST,
    output_type=gateway_dot_aws__iam__role__binding__pb2._AWSIAMROLEBINDING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAwsIamRoleBindings',
    full_name='gateway.Gateway.ListAwsIamRoleBindings',
    index=60,
    containing_service=None,
    input_type=gateway_dot_aws__iam__role__binding__pb2._LISTAWSIAMROLEBINDINGSREQUEST,
    output_type=gateway_dot_aws__iam__role__binding__pb2._LISTAWSIAMROLEBINDINGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAwsIamRoleBinding',
    full_name='gateway.Gateway.DeleteAwsIamRoleBinding',
    index=61,
    containing_service=None,
    input_type=gateway_dot_aws__iam__role__binding__pb2._DELETEAWSIAMROLEBINDINGREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReconcileCluster',
    full_name='gateway.Gateway.ReconcileCluster',
    index=62,
    containing_service=None,
    input_type=gateway_dot_cluster__pb2._RECONCILECLUSTERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReconcileNodePool',
    full_name='gateway.Gateway.ReconcileNodePool',
    index=63,
    containing_service=None,
    input_type=gateway_dot_node__pool__pb2._RECONCILENODEPOOLREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GATEWAY)

DESCRIPTOR.services_by_name['Gateway'] = _GATEWAY

# @@protoc_insertion_point(module_scope)
