# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/environment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/environment.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19gateway/environment.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x05\n\x0b\x45nvironment\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\ncreated_by\x18\x06 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x31\n\x05state\x18\n \x01(\x0e\x32\x1a.gateway.Environment.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x0b \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12:\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1e\n\x0e\x62\x61se_image_ref\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x19\n\timage_ref\x18\x04 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\"\n\x12snapshot_image_ref\x18\x08 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x0e\n\x06shared\x18\x0c \x01(\x08\x12?\n\x0b\x61nnotations\x18\t \x03(\x0b\x32%.gateway.Environment.AnnotationsEntryB\x03\xe0\x41\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x10\n\x0c\x44ISCONNECTED\x10\x02\x12\x0e\n\nCONNECTING\x10\x03\x12\r\n\tCONNECTED\x10\x04\x12\x11\n\rDISCONNECTING\x10\x05\x12\x10\n\x0cRECONNECTING\x10\x07\x12\x0c\n\x08\x44\x45LETING\x10\x06\"\x93\x01\n\x15\x45nvironmentConnection\x12\x19\n\x0cnode_pool_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tnum_ranks\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x12\x11\n\x04role\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x14\n\x04zone\x18\x05 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1e\n\x11use_local_storage\x18\x07 \x01(\x08\x42\x03\xe0\x41\x01\"|\n\x18\x43reateEnvironmentRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12.\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x14.gateway.EnvironmentB\x03\xe0\x41\x02\x12\x1b\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"*\n\x15GetEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x8b\x01\n\x17ListEnvironmentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"s\n\x18ListEnvironmentsResponse\x12*\n\x0c\x65nvironments\x18\x01 \x03(\x0b\x32\x14.gateway.Environment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"J\n\x18UpdateEnvironmentRequest\x12.\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x14.gateway.EnvironmentB\x03\xe0\x41\x02\"-\n\x18\x44\x65leteEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"I\n\x1e\x42\x61tchDeleteEnvironmentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\"\x84\x01\n\x19\x43onnectEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x37\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x03\xe0\x41\x02\x12\x1b\n\x0evscode_version\x18\x03 \x01(\tB\x03\xe0\x41\x01\"c\n\x1c\x44isconnectEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05\x66orce\x18\x02 \x01(\x08\x42\x03\xe0\x41\x01\x12\x1c\n\x0freset_snapshots\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_ENVIRONMENT_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.Environment.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISCONNECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONNECTING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONNECTED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISCONNECTING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECONNECTING', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=7, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=657,
  serialized_end=801,
)
_sym_db.RegisterEnumDescriptor(_ENVIRONMENT_STATE)


_ENVIRONMENT_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='gateway.Environment.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.Environment.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.Environment.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=654,
)

_ENVIRONMENT = _descriptor.Descriptor(
  name='Environment',
  full_name='gateway.Environment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.Environment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.Environment.display_name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.Environment.create_time', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='gateway.Environment.created_by', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.Environment.state', index=4,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.Environment.status', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='gateway.Environment.connection', index=6,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_image_ref', full_name='gateway.Environment.base_image_ref', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_ref', full_name='gateway.Environment.image_ref', index=8,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_image_ref', full_name='gateway.Environment.snapshot_image_ref', index=9,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared', full_name='gateway.Environment.shared', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='gateway.Environment.annotations', index=11,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ENVIRONMENT_ANNOTATIONSENTRY, ],
  enum_types=[
    _ENVIRONMENT_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=801,
)


_ENVIRONMENTCONNECTION = _descriptor.Descriptor(
  name='EnvironmentConnection',
  full_name='gateway.EnvironmentConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_pool_id', full_name='gateway.EnvironmentConnection.node_pool_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_ranks', full_name='gateway.EnvironmentConnection.num_ranks', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='gateway.EnvironmentConnection.role', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='gateway.EnvironmentConnection.zone', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_local_storage', full_name='gateway.EnvironmentConnection.use_local_storage', index=4,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=804,
  serialized_end=951,
)


_CREATEENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='CreateEnvironmentRequest',
  full_name='gateway.CreateEnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateEnvironmentRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='gateway.CreateEnvironmentRequest.environment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment_id', full_name='gateway.CreateEnvironmentRequest.environment_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1077,
)


_GETENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='GetEnvironmentRequest',
  full_name='gateway.GetEnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetEnvironmentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1121,
)


_LISTENVIRONMENTSREQUEST = _descriptor.Descriptor(
  name='ListEnvironmentsRequest',
  full_name='gateway.ListEnvironmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListEnvironmentsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListEnvironmentsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListEnvironmentsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListEnvironmentsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListEnvironmentsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1263,
)


_LISTENVIRONMENTSRESPONSE = _descriptor.Descriptor(
  name='ListEnvironmentsResponse',
  full_name='gateway.ListEnvironmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='environments', full_name='gateway.ListEnvironmentsResponse.environments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListEnvironmentsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListEnvironmentsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1265,
  serialized_end=1380,
)


_UPDATEENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='UpdateEnvironmentRequest',
  full_name='gateway.UpdateEnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='environment', full_name='gateway.UpdateEnvironmentRequest.environment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1382,
  serialized_end=1456,
)


_DELETEENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='DeleteEnvironmentRequest',
  full_name='gateway.DeleteEnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteEnvironmentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1458,
  serialized_end=1503,
)


_BATCHDELETEENVIRONMENTSREQUEST = _descriptor.Descriptor(
  name='BatchDeleteEnvironmentsRequest',
  full_name='gateway.BatchDeleteEnvironmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.BatchDeleteEnvironmentsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='gateway.BatchDeleteEnvironmentsRequest.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1578,
)


_CONNECTENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='ConnectEnvironmentRequest',
  full_name='gateway.ConnectEnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.ConnectEnvironmentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='gateway.ConnectEnvironmentRequest.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vscode_version', full_name='gateway.ConnectEnvironmentRequest.vscode_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1581,
  serialized_end=1713,
)


_DISCONNECTENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='DisconnectEnvironmentRequest',
  full_name='gateway.DisconnectEnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DisconnectEnvironmentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='gateway.DisconnectEnvironmentRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_snapshots', full_name='gateway.DisconnectEnvironmentRequest.reset_snapshots', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1715,
  serialized_end=1814,
)

_ENVIRONMENT_ANNOTATIONSENTRY.containing_type = _ENVIRONMENT
_ENVIRONMENT.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ENVIRONMENT.fields_by_name['state'].enum_type = _ENVIRONMENT_STATE
_ENVIRONMENT.fields_by_name['status'].message_type = gateway_dot_status__pb2._STATUS
_ENVIRONMENT.fields_by_name['connection'].message_type = _ENVIRONMENTCONNECTION
_ENVIRONMENT.fields_by_name['annotations'].message_type = _ENVIRONMENT_ANNOTATIONSENTRY
_ENVIRONMENT_STATE.containing_type = _ENVIRONMENT
_CREATEENVIRONMENTREQUEST.fields_by_name['environment'].message_type = _ENVIRONMENT
_LISTENVIRONMENTSRESPONSE.fields_by_name['environments'].message_type = _ENVIRONMENT
_UPDATEENVIRONMENTREQUEST.fields_by_name['environment'].message_type = _ENVIRONMENT
_CONNECTENVIRONMENTREQUEST.fields_by_name['connection'].message_type = _ENVIRONMENTCONNECTION
DESCRIPTOR.message_types_by_name['Environment'] = _ENVIRONMENT
DESCRIPTOR.message_types_by_name['EnvironmentConnection'] = _ENVIRONMENTCONNECTION
DESCRIPTOR.message_types_by_name['CreateEnvironmentRequest'] = _CREATEENVIRONMENTREQUEST
DESCRIPTOR.message_types_by_name['GetEnvironmentRequest'] = _GETENVIRONMENTREQUEST
DESCRIPTOR.message_types_by_name['ListEnvironmentsRequest'] = _LISTENVIRONMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListEnvironmentsResponse'] = _LISTENVIRONMENTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateEnvironmentRequest'] = _UPDATEENVIRONMENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteEnvironmentRequest'] = _DELETEENVIRONMENTREQUEST
DESCRIPTOR.message_types_by_name['BatchDeleteEnvironmentsRequest'] = _BATCHDELETEENVIRONMENTSREQUEST
DESCRIPTOR.message_types_by_name['ConnectEnvironmentRequest'] = _CONNECTENVIRONMENTREQUEST
DESCRIPTOR.message_types_by_name['DisconnectEnvironmentRequest'] = _DISCONNECTENVIRONMENTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Environment = _reflection.GeneratedProtocolMessageType('Environment', (_message.Message,), {

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ENVIRONMENT_ANNOTATIONSENTRY,
    '__module__' : 'gateway.environment_pb2'
    # @@protoc_insertion_point(class_scope:gateway.Environment.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _ENVIRONMENT,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.Environment)
  })
_sym_db.RegisterMessage(Environment)
_sym_db.RegisterMessage(Environment.AnnotationsEntry)

EnvironmentConnection = _reflection.GeneratedProtocolMessageType('EnvironmentConnection', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTCONNECTION,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.EnvironmentConnection)
  })
_sym_db.RegisterMessage(EnvironmentConnection)

CreateEnvironmentRequest = _reflection.GeneratedProtocolMessageType('CreateEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENVIRONMENTREQUEST,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateEnvironmentRequest)
  })
_sym_db.RegisterMessage(CreateEnvironmentRequest)

GetEnvironmentRequest = _reflection.GeneratedProtocolMessageType('GetEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENVIRONMENTREQUEST,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetEnvironmentRequest)
  })
_sym_db.RegisterMessage(GetEnvironmentRequest)

ListEnvironmentsRequest = _reflection.GeneratedProtocolMessageType('ListEnvironmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENVIRONMENTSREQUEST,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListEnvironmentsRequest)
  })
_sym_db.RegisterMessage(ListEnvironmentsRequest)

ListEnvironmentsResponse = _reflection.GeneratedProtocolMessageType('ListEnvironmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENVIRONMENTSRESPONSE,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListEnvironmentsResponse)
  })
_sym_db.RegisterMessage(ListEnvironmentsResponse)

UpdateEnvironmentRequest = _reflection.GeneratedProtocolMessageType('UpdateEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENVIRONMENTREQUEST,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateEnvironmentRequest)
  })
_sym_db.RegisterMessage(UpdateEnvironmentRequest)

DeleteEnvironmentRequest = _reflection.GeneratedProtocolMessageType('DeleteEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENVIRONMENTREQUEST,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteEnvironmentRequest)
  })
_sym_db.RegisterMessage(DeleteEnvironmentRequest)

BatchDeleteEnvironmentsRequest = _reflection.GeneratedProtocolMessageType('BatchDeleteEnvironmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHDELETEENVIRONMENTSREQUEST,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.BatchDeleteEnvironmentsRequest)
  })
_sym_db.RegisterMessage(BatchDeleteEnvironmentsRequest)

ConnectEnvironmentRequest = _reflection.GeneratedProtocolMessageType('ConnectEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTENVIRONMENTREQUEST,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ConnectEnvironmentRequest)
  })
_sym_db.RegisterMessage(ConnectEnvironmentRequest)

DisconnectEnvironmentRequest = _reflection.GeneratedProtocolMessageType('DisconnectEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTENVIRONMENTREQUEST,
  '__module__' : 'gateway.environment_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DisconnectEnvironmentRequest)
  })
_sym_db.RegisterMessage(DisconnectEnvironmentRequest)


DESCRIPTOR._options = None
_ENVIRONMENT_ANNOTATIONSENTRY._options = None
_ENVIRONMENT.fields_by_name['name']._options = None
_ENVIRONMENT.fields_by_name['display_name']._options = None
_ENVIRONMENT.fields_by_name['create_time']._options = None
_ENVIRONMENT.fields_by_name['created_by']._options = None
_ENVIRONMENT.fields_by_name['state']._options = None
_ENVIRONMENT.fields_by_name['status']._options = None
_ENVIRONMENT.fields_by_name['connection']._options = None
_ENVIRONMENT.fields_by_name['base_image_ref']._options = None
_ENVIRONMENT.fields_by_name['image_ref']._options = None
_ENVIRONMENT.fields_by_name['snapshot_image_ref']._options = None
_ENVIRONMENT.fields_by_name['annotations']._options = None
_ENVIRONMENTCONNECTION.fields_by_name['node_pool_id']._options = None
_ENVIRONMENTCONNECTION.fields_by_name['num_ranks']._options = None
_ENVIRONMENTCONNECTION.fields_by_name['role']._options = None
_ENVIRONMENTCONNECTION.fields_by_name['zone']._options = None
_ENVIRONMENTCONNECTION.fields_by_name['use_local_storage']._options = None
_CREATEENVIRONMENTREQUEST.fields_by_name['parent']._options = None
_CREATEENVIRONMENTREQUEST.fields_by_name['environment']._options = None
_CREATEENVIRONMENTREQUEST.fields_by_name['environment_id']._options = None
_GETENVIRONMENTREQUEST.fields_by_name['name']._options = None
_LISTENVIRONMENTSREQUEST.fields_by_name['parent']._options = None
_LISTENVIRONMENTSREQUEST.fields_by_name['page_size']._options = None
_LISTENVIRONMENTSREQUEST.fields_by_name['page_token']._options = None
_LISTENVIRONMENTSREQUEST.fields_by_name['filter']._options = None
_LISTENVIRONMENTSREQUEST.fields_by_name['order_by']._options = None
_UPDATEENVIRONMENTREQUEST.fields_by_name['environment']._options = None
_DELETEENVIRONMENTREQUEST.fields_by_name['name']._options = None
_BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['parent']._options = None
_BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['names']._options = None
_CONNECTENVIRONMENTREQUEST.fields_by_name['name']._options = None
_CONNECTENVIRONMENTREQUEST.fields_by_name['connection']._options = None
_CONNECTENVIRONMENTREQUEST.fields_by_name['vscode_version']._options = None
_DISCONNECTENVIRONMENTREQUEST.fields_by_name['name']._options = None
_DISCONNECTENVIRONMENTREQUEST.fields_by_name['force']._options = None
_DISCONNECTENVIRONMENTREQUEST.fields_by_name['reset_snapshots']._options = None
# @@protoc_insertion_point(module_scope)
