# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/sign_in.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/sign_in.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15gateway/sign_in.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\"\x8f\x01\n\rSignInRequest\x12\x41\n\x0eoauth_provider\x18\x01 \x01(\x0e\x32$.gateway.SignInRequest.OAuthProviderB\x03\xe0\x41\x02\";\n\rOAuthProvider\x12\x1e\n\x1aOAUTH_PROVIDER_UNSPECIFIED\x10\x00\x12\n\n\x06GOOGLE\x10\x01\"3\n\x18GetOAuthArgumentsRequest\x12\x17\n\naccount_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"B\n\x19GetOAuthArgumentsResponse\x12\x12\n\nissuer_url\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\tB\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,])



_SIGNINREQUEST_OAUTHPROVIDER = _descriptor.EnumDescriptor(
  name='OAuthProvider',
  full_name='gateway.SignInRequest.OAuthProvider',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OAUTH_PROVIDER_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=152,
  serialized_end=211,
)
_sym_db.RegisterEnumDescriptor(_SIGNINREQUEST_OAUTHPROVIDER)


_SIGNINREQUEST = _descriptor.Descriptor(
  name='SignInRequest',
  full_name='gateway.SignInRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oauth_provider', full_name='gateway.SignInRequest.oauth_provider', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNINREQUEST_OAUTHPROVIDER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=211,
)


_GETOAUTHARGUMENTSREQUEST = _descriptor.Descriptor(
  name='GetOAuthArgumentsRequest',
  full_name='gateway.GetOAuthArgumentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='gateway.GetOAuthArgumentsRequest.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=264,
)


_GETOAUTHARGUMENTSRESPONSE = _descriptor.Descriptor(
  name='GetOAuthArgumentsResponse',
  full_name='gateway.GetOAuthArgumentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer_url', full_name='gateway.GetOAuthArgumentsResponse.issuer_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='gateway.GetOAuthArgumentsResponse.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=332,
)

_SIGNINREQUEST.fields_by_name['oauth_provider'].enum_type = _SIGNINREQUEST_OAUTHPROVIDER
_SIGNINREQUEST_OAUTHPROVIDER.containing_type = _SIGNINREQUEST
DESCRIPTOR.message_types_by_name['SignInRequest'] = _SIGNINREQUEST
DESCRIPTOR.message_types_by_name['GetOAuthArgumentsRequest'] = _GETOAUTHARGUMENTSREQUEST
DESCRIPTOR.message_types_by_name['GetOAuthArgumentsResponse'] = _GETOAUTHARGUMENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignInRequest = _reflection.GeneratedProtocolMessageType('SignInRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINREQUEST,
  '__module__' : 'gateway.sign_in_pb2'
  # @@protoc_insertion_point(class_scope:gateway.SignInRequest)
  })
_sym_db.RegisterMessage(SignInRequest)

GetOAuthArgumentsRequest = _reflection.GeneratedProtocolMessageType('GetOAuthArgumentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOAUTHARGUMENTSREQUEST,
  '__module__' : 'gateway.sign_in_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetOAuthArgumentsRequest)
  })
_sym_db.RegisterMessage(GetOAuthArgumentsRequest)

GetOAuthArgumentsResponse = _reflection.GeneratedProtocolMessageType('GetOAuthArgumentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOAUTHARGUMENTSRESPONSE,
  '__module__' : 'gateway.sign_in_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetOAuthArgumentsResponse)
  })
_sym_db.RegisterMessage(GetOAuthArgumentsResponse)


DESCRIPTOR._options = None
_SIGNINREQUEST.fields_by_name['oauth_provider']._options = None
_GETOAUTHARGUMENTSREQUEST.fields_by_name['account_id']._options = None
# @@protoc_insertion_point(module_scope)
